Package: archeofrag
Type: Package
Title: Spatial Analysis in Archaeology from Refitting Fragments
Version: 1.2.4
Date: 2026-04-22
Authors@R: person("Sebastien", "Plutniak", email = "sebastien.plutniak@posteo.net", role = c("aut", "cre"), comment = c(ORCID = "0000-0002-6674-3806"))
Author: Sebastien Plutniak [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6674-3806>)
Maintainer: Sebastien Plutniak <sebastien.plutniak@posteo.net>
Description: Methods to analyse spatial units in archaeology from the refitting relationships between fragments of objects scattered in these units (e.g. stratigraphic layers). Graphs are used to model archaeological observations. The package is mainly based on the 'igraph' package for graph analysis. Functions can: 1) create, manipulate, visualise, and simulate fragmentation graphs, 2) measure the cohesion and admixture of archaeological spatial units, and 3) characterise the topology of a specific set of refitting relationships. A series of published empirical datasets is included. Documentation about 'archeofrag' is provided by a vignette and by the accompanying scientific papers: Plutniak (2021, Journal of Archaeological Science, <doi:10.1016/j.jas.2021.105501>) and Plutniak (2022, Journal of Open Source Software, <doi:10.21105/joss.04335>). This package is complemented by the 'archeofrag.gui' R package, a companion GUI application available at <https://analytics.huma-num.fr/Sebastien.Plutniak/archeofrag/>.
License: GPL-3
Repository: CRAN
Encoding: UTF-8
LazyData: true
Depends: R (>= 3.5.0)
Imports: igraph, graphics, stats, grDevices, methods, utils
Suggests: RBGL, knitr, covr, rmarkdown, markdown, testthat (>= 3.0.0)
Config/testthat/edition: 3
VignetteBuilder: knitr
URL: https://github.com/sebastien-plutniak/archeofrag
BugReports: https://github.com/sebastien-plutniak/archeofrag/issues
NeedsCompilation: no
Packaged: 2026-04-21 22:42:47 UTC; seb
Date/Publication: 2026-04-22 07:10:09 UTC
Built: R 4.6.0; ; 2026-04-26 02:40:09 UTC; unix
