export(frag.cycles)
export(frag.diameters)
export(frag.edges.weighting)
export(frag.get.layers)
export(frag.get.layers.pair)
export(frag.graph.plot)
export(frag.graph.reduce)
export(frag.layers.admixture)
export(frag.layers.cohesion)
export(frag.get.parameters)
export(frag.observer.failure)
export(frag.path.lengths)
export(frag.relations.by.layers)
export(frag.simul.process)
export(frag.simul.compare)
export(frag.cohesion.ranking)
export(frag.simul.summarise)
export(make_cr_graph)
export(make_sr_graph)
export(make_crsr_graph)
export(make_frag_object)
exportClasses(Frag.object)
importFrom(grDevices, rgb)
importFrom(graphics, plot, hist)
importFrom(methods, new)
importFrom(utils, combn)
importFrom(stats, na.omit, sd, wilcox.test, median, mad)
importFrom(igraph,
	add_edges, 
	add_layout_, 
	add_vertices, 
	as_edgelist, 
	as_graphnel,
	articulation_points,
	bibcoupling, 
	components, 
	component_wise, 
	complementer,
	"%--%",
	decompose, 
	degree,
	delete_graph_attr,
	delete_vertex_attr, 
	delete_vertices, 
	diameter, 
	distance_table, 
	E, 
	edge_attr, 
	ego,
	gorder, 
	graph_attr, 
	graph_from_adjacency_matrix, 
	graph_from_data_frame, 
	gsize, 
	induced_subgraph, 
	is_igraph, 
	is_directed,
	layout_with_fr, 
	make_ring, 
	make_graph,
	plot.igraph, 
	set_graph_attr, 
	set_vertex_attr, 
	simplify, 
	subgraph_from_edges, 
	subgraph_isomorphisms, 
	transitivity, 
	union,
	V, 
	vertex_attr, 
	vertex_attr_names, 
	with_fr) 

